---
title: "Community Curation"
date: "2025-06-26"
summary: "The importance of creating safe online spaces for LGBTQ+ people"
---

Hi friends! For those who do not know me, I am Naomi and my pronouns are she/her. I am a Developer Experience Engineer at Deepgram, with a heavy focus on community tooling and infrastructure, and the Community Manager at freeCodeCamp. I have a strong background in community building and community management. I wanted to take some time today to write about how you can cultivate an inclusive and welcoming community for all of your users.

## Why is creating inclusive online spaces so important?

People of marginalised identities continue to face discrimination in professional environments, both in cyberspace and in meatspace. These barriers increase the friction they encounter when trying to succeed in our industry. By creating safe spaces for folks regardless of their identity, we can help tear down some of those barriers and foster a healthier culture.

Online platforms such as Discord or Reddit also offer a certain level of pseudo-anonymity. This means that a medium like a Discord server can provide a space where folks can safely explore their identity. In fact, it was because of the encouraging community at TweetShift that I was able to find my own identity and determine my path toward happiness in life.

  <figure style="display: grid; grid-template-areas: 'img1 img2' 'caption caption';">
    <img style="grid-area: img1;" width=300 src="https://cdn.nhcarrigan.com/blog/cultivating-community-1.png" alt="An infographic from the Women Tech Network featuring statistics about LGBTQ+ representation in the workforce. The image has an orange-to-yellow gradient background at the top with 'womentech network' in white lowercase letters. The main content is on a light gray background with 'ONLY' in large gray text, followed by '2-3%' in colorful letters (orange 2, yellow hyphen, green 3, blue percent sign). Below that, gray text reads 'OF THE WORKFORCE IDENTIFY AS' followed by 'LGBTQ+' in rainbow colors matching the pride flag (red L, orange G, yellow B, green T, blue Q, purple plus sign). On the right side are six raised fists in pride flag colors (red, orange, yellow, green, blue, purple) with celebratory confetti or streamers scattered around them in matching colors.">
    <img style="grid-area: img2;" width=300 src="https://cdn.nhcarrigan.com/blog/cultivating-community-2.png" alt="A colorful infographic from WomenTech Network featuring a gradient background that transitions from orange and yellow at the top to purple and teal at the bottom. The WomenTech Network logo appears at the top in white text. The main statistic is displayed in large white text stating '46% OF LGBTQ+ EMPLOYEES ARE NOT OPEN ABOUT THEIR IDENTITIES AT WORK.' Below this text is a circular chart with a dark purple center containing '46%' in white text, surrounded by a ring that is approximately 46% yellow and 54% light gray, visually representing the statistic. The background features subtle decorative elements including rounded rectangular shapes in darker tones that complement the gradient color scheme.">
    <figcaption style="grid-area: caption; text-align: center;">Statistics sourced from a www.womentech.net blog post</figcaption>
  </figure>

The impact that the LGBT community has on our industry is often understated. Consider that while roughly 3% of our industry's workforce actively identify as LGBT, 46% of the folks who _would_ identify do not feel safe to do so. Which means that 3% could be as high as 6%! By cultivating inclusive and public tech spaces, we open doors for the future generation of developers - the LGBT folks who are looking for mentors or role models "like themselves" can find those people and engage with them in a safe community.

## But how can I create an inclusive community?

Well, there are a few things you can do.

<figure>
    <img width=600 src="https://cdn.nhcarrigan.com/blog/cultivating-community-3.png" alt="A screenshot of a pronoun selection interface with a dark purple gradient background. At the top in white text is the heading 'Let's get to know each other! What are your pronouns?' with a red asterisk indicating a required field. Below are nine pronoun options arranged in a 3x3 grid: Top row: 'Fae/Faer' (with description about faer friends asking if the server belonged to faer), 'He/Him' (with description about his friends asking if the server belonged to him), and 'It/Its' (with description about its friends asking if the server belonged to it). Middle row: 'She/Her' (highlighted with a blue border and checkmark, indicating it's selected, with description about her friends asking if the server belonged to her), 'They/Them' (with description about their friends asking if the server belonged to them), and 'Xe/Xem' (with description about xyr friends asking if the server belonged to xem). Bottom row: 'Ze/Zir' (with description about zir friends asking if the server belonged to zir), 'Ask' (for those whose pronouns change frequently or prefer people ask), and 'I use neopronouns' (noting that the ones used aren't listed). At the bottom are two additional options: 'Any' (indicating no preference for how to be referred to) and 'Use my name' (preferring to be referred to by name rather than pronouns). The interface notes 'Choose all that apply' at the bottom left.">
    <figcaption>The pronoun roles available in the freeCodeCamp Discord.</figcaption>
</figure>

Our first example is more Discord specific: you can provide pronoun roles for members to select to self-identify how they wish to be addressed. There are a couple of key components to this. First, in every community I run I make these roles _mandatory_. By doing so, I start to tear down the assumption that only LGBT people would select pronouns. When you normalise this as the standard for **everyone**, folks are no longer "outing themselves" just for selecting a role. Second, it is important to provide a decent array of options. Too often, I see roles limited to "she/her", "he/him", and "they/them". As the LGBT community grows, we continue to see folks using pronouns like "it/its", or using neopronouns like "fae/faer" or "ze/zyr". Offering roles to cover your community's less common pronouns creates a more welcoming space, and for folks who use neopronouns that you do not have a role for, offering an "ask my pronouns" or "i use neopronouns" role can help.

Your next task is to create community policies, such as a Code of Conduct, that specifically enforce an inclusive environment. For example, [my community's Code of Conduct](https://docs.nhcarrigan.com/community/coc) includes verbiage about not challenging or questioning someone's identity (such as "those aren't real pronouns"), and disallowing debates of the rights of marginalised communities (such as "trans people don't need to use the restroom they identify with"). If you are interested, I would be happy to help you construct your own Code of Conduct.

But these policies are meaningless if they are not enforced. And when you enforce them, you _must_ be aware of how your enforcement decision might appear to the community. For example, if someone uses a slur, then tries to justify it as "I was just joking", it may seem tempting to let them off with a warning. But I would immediately ban the user from the community in such a case, because doing so sets the precedent for the other members that toxic behaviour will not be tolerated even as a "joke".

You also need to be cognisant of your own language choices. As a community leader, you need to set the example for the rest of your members. Being aware of things like folks' pronouns, avoiding language like "cr\*zy" that might seem okay but has a history of being used to harm people, and carrying yourself in a way that demonstrates how you want your members to interact are all important considerations. You may even want to consider avoiding phrases like "Hey guys", which implicitly assumes that "male" is the default gender.

Finally, the space must be made for folks who are uninformed, rather than bigoted. Someone who comes in and comments that trans people should not have bathroom access is bigoted. Someone who comes in and asks why the bathroom legislation seems like "such a big deal" might just be uninformed. Creating a space where folks can ask their questions and become educated will empower people to become positive allies, or even discover their own identity.

## How does this help my business or organisation?

One of the biggest benefits of curating these communities is that you can avoid negative optics. For example, let us consider Hyprland. For those who are not familiar, Hyprland is a window manager for Linux that gained quite a bit of popularity for the feature set it offers.

<figure>
    <img width=600 src="https://cdn.nhcarrigan.com/blog/cultivating-community-4.png" alt="A screenshot of text discussing issues with Hyprland's community. The text is displayed in a monospace font on a light gray background. The content describes how the author became aware of problems with hateful incidents in Hyprland's Discord community. The text explains that the community tolerates hate speech when presented with 'a veneer of decorum or sarcasm' and dismisses it as jokes when challenged. It specifically mentions an incident where Discord moderators harassed a transgender user by changing their pronouns from 'they/she' to 'who/cares' using moderator privileges. The text concludes by stating that community leaders set examples that define acceptable behavior, and that "the problem comes from the top down."">
    <figcaption>Anecdote about Hyprland's community, sourced from drewdevault.com</figcaption>
</figure>

However, the community around this app has a very rough history of bigotry and harassment of marginalised peoples.

<figure>
    <img width=600 src="https://cdn.nhcarrigan.com/blog/cultivating-community-5.png" alt="A Discord message from user 'anna [it/its]' with a green online indicator, posted on 24/03/2025 at 13:28. The message is tagged with '@minor announcements' and titled 'new decision re. hyprland:'. The message content explains that hyprland is a Wayland compositor implementing a tiling window manager with gestures and animations, noting that the main developer vaxry has a controversial internet presence they don't want to discuss. The message states that asking for support with hyprland is acceptable, as is mentioning its use, but requests that discussions about vaxry's behavior or political views be kept to the #controversial channel, especially advising against bringing up the topic when someone mentions hyprland outside of that channel. The word '(edited)' appears at the end of the message.">
    <figcaption>An announcement made in the Arch Linux Community Discord.</figcaption>
</figure>

The negative optics got so bad, in fact, that the Arch Linux Discord community had to explicitly ban discussions around the controversy - because every time Hyprland was mentioned, it turned into "YOU USE THAT? DO YOU HATE LGBT PEOPLE??". Which is definitely **not a phrase** you want people to use when describing your organisation.

On the flip side, then, you can also gain some positive word of mouth advertising. Members of marginalised identities who feel safe in your community are much more likely to become evangelists. A queer person who has a better experience with your community than a competitor's community, as an example, will tend to recommend your products first - because they felt _safe_ in your space. They may even do so if your product feels inferior than the competitor's to them!

This can also trickle up into new talent for your teams. When marginalised folk feel safe in your public communities, the impression can be created that your internal spaces and teams are also safe. This means that LGBT people might be more likely to apply to work for you when you have a healthier community.

All of these, then, create opportunity for sweet sweet revenue. Whether you are driving sales and conversions by providing comfortable opportunities for users to explore your product, or capturing new talent that other companies might miss out on, you can leverage your community health to create growth for your organisation.

## But who can help with this?

First, your community leaders are the most important champions here. When your leaders conduct themselves in a way that embodies the inclusive environment you want for your community, then you set the standard for engagement which your community members will follow.

Your community members, then, can also help with this! By following the guidelines you have established and ensuring their behaviour is in line with those guidelines, they can contribute to the well-being of the community. But it does not stop there! When a community is truly successful at inclusion, members will help inform each other about opportunities to improve and grow.

So really, the answer is _everyone_ can help with this! Even people who are not actively part of your community can still be valuable sources of information and opportunities for growth.

Which brings me to my final point:

## Always keep an open mind!

None of us will have all of the answers. It is simply impossible. Even as someone who lives these experiences daily, I do not have all of the answers. It is important that we allow ourselves the space to be wrong, the opportunity to improve, and the ability to handle our missteps with grace.

I look forward to seeing the positive impact you will have on your communities. If you have any questions or would like to schedule some time to explore this further, please feel free to [reach out in our Discord](https://chat.nhcarrigan.com). Thank you for your time, and happy pride!
